==> lite_tools-0.4.10.5b1-py3-none-any.whl: lite_tools/utils/u_re_time.py <==
# -*- coding: utf-8 -*-
# @Author  : Lodge
"""
      ┏┛ ┻━━━━━┛ ┻┓
      ┃　　　　　　 ┃
      ┃　　　━　　　┃
      ┃　┳┛　  ┗┳　┃
      ┃　　　　　　 ┃
      ┃　　　┻　　　┃
      ┃　　　　　　 ┃
      ┗━┓　　　┏━━━┛
        ┃　　　┃   神兽保佑
        ┃　　　┃   代码无BUG！
        ┃　　　┗━━━━━━━━━┓
        ┃　　　　　　　    ┣┓
        ┃　　　　         ┏┛
        ┗━┓ ┓ ┏━━━┳ ┓ ┏━┛
          ┃ ┫ ┫   ┃ ┫ ┫
          ┗━┻━┛   ┗━┻━┛
具体的实现逻辑就是  时间的修改匹配规则-- 注意兼容英文 中文 数字
一级匹配规则：
几秒前
几分钟前
几小时前
几天前
几周前
几年前

二级匹配规则:
年 -> 如果没有拿到就获取       今年
月 -> 没有拿到看看有没有就获取  当月
日 -> 没有就取                当天

三级处理规则：
提取到的相关字符串转换为 time 识别的时间字符串样式

输出:
时间戳 --> 10位时间戳

"""

# 一些常用的匹配规则
NORMAL_PATTERN = [
    (r"^\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}$", "%Y-%m-%d %H:%M:%S"),  # 优先匹配最常用的模板
    (r"^\d{2}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}$", "%y-%m-%d %H:%M:%S"),  # 优先匹配最常用的模板
    (r"^\d{4}$", "%Y"),
    (r"^\d{2}$", "%y"),
    (r"^\d{4}-\d{2}$", "%Y-%m"),
    (r"^\d{2}-\d{2}$", "%y-%m"),
    (r"^\d{4}\.\d{2}$", "%Y.%m"),
    (r"^\d{2}\.\d{2}$", "%y.%m"),
    (r"^\d{4}年\d{2}月$", "%Y年%m月"),
    (r"^\d{2}年\d{2}月$", "%y年%m月"),
    (r"^\d{4}-\d{2}-\d{2}$", "%Y-%m-%d"),
    (r"^\d{2}-\d{2}-\d{2}$", "%y-%m-%d"),
    (r"^\d{4}\.\d{2}\.\d{2}$", "%Y.%m.%d"),
    (r"^\d{2}\.\d{2}\.\d{2}$", "%y.%m.%d"),
    (r"^\d{4}/\d{2}/\d{2}$", "%Y/%m/%d"),
    (r"^\d{2}/\d{2}/\d{2}$", "%y/%m/%d"),
    (r"^\d{4}年\d{2}月\d{2}日$", "%Y年%m月%d日"),
    (r"^\d{2}年\d{2}月\d{2}日$", "%y年%m月%d日"),
    (r"^\d{4}年\d{2}月\d{2}日 \d{2}:\d{2}$", "%Y年%m月%d日 %H:%M"),
    (r"^\d{2}年\d{2}月\d{2}日 \d{2}:\d{2}$", "%y年%m月%d日 %H:%M"),
    (r"^\d{4}年\d{2}月\d{2}日 \d{2}:\d{2}:\d{2}$", "%Y年%m月%d日 %H:%M:%S"),
    (r"^\d{2}年\d{2}月\d{2}日 \d{2}:\d{2}:\d{2}$", "%y年%m月%d日 %H:%M:%S"),
    (r"^\d{4}/\d{2}/\d{2} \d{2}:\d{2}:\d{2}$", "%Y/%m/%d %H:%M:%S"),
    (r"^\d{2}/\d{2}/\d{2} \d{2}:\d{2}:\d{2}$", "%y/%m/%d %H:%M:%S"),
    (r"^\d{4}\.\d{2}\.\d{2} \d{2}:\d{2}:\d{2}$", "%Y.%m.%d %H:%M:%S"),
    (r"^\d{2}\.\d{2}\.\d{2} \d{2}:\d{2}:\d{2}$", "%y.%m.%d %H:%M:%S"),
    (r"^\d{4}/\d{2}/\d{2} \d{2}:\d{2}$", "%Y/%m/%d %H:%M"),
    (r"^\d{2}/\d{2}/\d{2} \d{2}:\d{2}$", "%y/%m/%d %H:%M"),
    (r"^\d{4}-\d{2}-\d{2} \d{2}:\d{2}$", "%Y-%m-%d %H:%M"),
    (r"^\d{2}-\d{2}-\d{2} \d{2}:\d{2}$", "%y-%m-%d %H:%M"),
    (r"^\d{4}\.\d{2}\.\d{2} \d{2}:\d{2}$", "%Y.%m.%d %H:%M"),
    (r"^\d{2}\.\d{2}\.\d{2} \d{2}:\d{2}$", "%y.%m.%d %H:%M"),
]


# 此处pattern直接引用的KingName 南哥的GNE里面的匹配规则 站在巨人肩膀优化代码
# https://github.com/GeneralNewsExtractor/GeneralNewsExtractor/blob/master/gne/defaults.py
DATETIME_PATTERN = {
    r"(\d{4}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[0-1]?[0-9]:[0-5]?[0-9]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M", "S")],
    r"(\d{4}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[2][0-3]:[0-5]?[0-9]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M", "S")],
    r"(\d{4}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[0-1]?[0-9]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M")],
    r"(\d{4}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[2][0-3]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M")],
    # r"(\d{4}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[1-24]\d时[0-60]\d分)([1-24]\d时)": [("Y", "m", "d", "H", "M"), ("H",)],
    r"(\d{4}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[0-23]时[0-59]分)([0-23]时)": [("Y", "m", "d", "H", "M"), ("H",)],
    r"(\d{2}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[0-1]?[0-9]:[0-5]?[0-9]:[0-5]?[0-9])": [("y", "m", "d", "H", "M", "S")],
    r"(\d{2}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[2][0-3]:[0-5]?[0-9]:[0-5]?[0-9])": [("y", "m", "d", "H", "M", "S")],
    r"(\d{2}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[0-1]?[0-9]:[0-5]?[0-9])": [("y", "m", "d", "H", "M")],
    r"(\d{2}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[2][0-3]:[0-5]?[0-9])": [("y", "m", "d", "H", "M")],
    # r"(\d{2}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[1-24]\d时[0-60]\d分)([1-24]\d时)": [("y", "m", "d", "H", "M"), ("H",)],
    r"(\d{2}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[0-23]时[0-59]分)([0-23]时)": [("y", "m", "d", "H", "M"), ("H",)],
    r"(\d{4}年\d{1,2}月\d{1,2}日\s*?[0-1]?[0-9]:[0-5]?[0-9]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M", "S")],
    r"(\d{4}年\d{1,2}月\d{1,2}日\s*?[2][0-3]:[0-5]?[0-9]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M", "S")],
    r"(\d{4}年\d{1,2}月\d{1,2}日\s*?[0-1]?[0-9]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M")],
    r"(\d{4}年\d{1,2}月\d{1,2}日\s*?[2][0-3]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M")],
    # r"(\d{4}年\d{1,2}月\d{1,2}日\s*?[1-24]\d时[0-60]\d分)([1-24]\d时)": [("Y", "m", "d", "H", "M"), ("H",)],
    r"(\d{4}年\d{1,2}月\d{1,2}日\s*?[0-23]时[0-59]分)([0-23]时)": [("Y", "m", "d", "H", "M"), ("H",)],
    r"(\d{2}年\d{1,2}月\d{1,2}日\s*?[0-1]?[0-9]:[0-5]?[0-9]:[0-5]?[0-9])": [("y", "m", "d", "H", "M", "S")],
    r"(\d{2}年\d{1,2}月\d{1,2}日\s*?[2][0-3]:[0-5]?[0-9]:[0-5]?[0-9])": [("y", "m", "d", "H", "M", "S")],
    r"(\d{2}年\d{1,2}月\d{1,2}日\s*?[0-1]?[0-9]:[0-5]?[0-9])": [("y", "m", "d", "H", "M", "S")],
    r"(\d{2}年\d{1,2}月\d{1,2}日\s*?[2][0-3]:[0-5]?[0-9])": [("y", "m", "d", "H", "M")],
    # r"(\d{2}年\d{1,2}月\d{1,2}日\s*?[1-24]\d时[0-60]\d分)([1-24]\d时)": [("y", "m", "d", "H", "M"), ("H",)],
    r"(\d{2}年\d{1,2}月\d{1,2}日\s*?[0-23]时[0-59]分)([0-23]时)": [("y", "m", "d", "H", "M"), ("H",)],
    r"(\d{1,2}月\d{1,2}日\s*?[0-1]?[0-9]:[0-5]?[0-9]:[0-5]?[0-9])": [("m", "d", "H", "M", "S")],
    r"(\d{1,2}月\d{1,2}日\s*?[2][0-3]:[0-5]?[0-9]:[0-5]?[0-9])": [("m", "d", "H", "M", "S")],
    r"(\d{1,2}月\d{1,2}日\s*?[0-1]?[0-9]:[0-5]?[0-9])": [("m", "d", "H", "M")],
    r"(\d{1,2}月\d{1,2}日\s*?[2][0-3]:[0-5]?[0-9])": [("m", "d", "H", "M")],
    # r"(\d{1,2}月\d{1,2}日\s*?[1-24]\d时[0-60]\d分)([1-24]\d时)": [("m", "d", "H", "M"), ("H",)],
    r"(\d{1,2}月\d{1,2}日\s*?[0-23]时[0-59]分)([0-23]时)": [("m", "d", "H", "M"), ("H",)],
    r"(\d{4}[-|/|.]\d{1,2}[-|/|.]\d{1,2})": [("Y", "m", "d")],
    r"(\d{2}[-|/|.]\d{1,2}[-|/|.]\d{1,2})": [("y", "m", "d")],
    r"(\d{4}年\d{1,2}月\d{1,2}日)": [("Y", "m", "d")],
    r"(\d{2}年\d{1,2}月\d{1,2}日)": [("y", "m", "d")],
    r"(\d{1,2}月\d{1,2}日)": [("m", "d")]
}

==> lite_tools-0.4.10.10-py3-none-any.whl: lite_tools/utils/u_re_time.py <==
# -*- coding: utf-8 -*-
# @Author  : Lodge
"""
      ┏┛ ┻━━━━━┛ ┻┓
      ┃　　　　　　 ┃
      ┃　　　━　　　┃
      ┃　┳┛　  ┗┳　┃
      ┃　　　　　　 ┃
      ┃　　　┻　　　┃
      ┃　　　　　　 ┃
      ┗━┓　　　┏━━━┛
        ┃　　　┃   神兽保佑
        ┃　　　┃   代码无BUG！
        ┃　　　┗━━━━━━━━━┓
        ┃　　　　　　　    ┣┓
        ┃　　　　         ┏┛
        ┗━┓ ┓ ┏━━━┳ ┓ ┏━┛
          ┃ ┫ ┫   ┃ ┫ ┫
          ┗━┻━┛   ┗━┻━┛
具体的实现逻辑就是  时间的修改匹配规则-- 注意兼容英文 中文 数字
一级匹配规则：
几秒前
几分钟前
几小时前
几天前
几周前
几年前

二级匹配规则:
年 -> 如果没有拿到就获取       今年
月 -> 没有拿到看看有没有就获取  当月
日 -> 没有就取                当天

三级处理规则：
提取到的相关字符串转换为 time 识别的时间字符串样式

输出:
时间戳 --> 10位时间戳

"""

# 一些常用的匹配规则
# 匹配正则 对应格式 需要补充当日的字段
NORMAL_PATTERN = [
    (r"^\d{8}$", "%Y%m%d", ""),
    (r"^\d{6}$", "%y%m%d", ""),
    (r"^\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}$", "%Y-%m-%d %H:%M:%S", ""),  # 优先匹配最常用的模板
    (r"^\d{2}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}$", "%y-%m-%d %H:%M:%S", ""),  # 优先匹配最常用的模板
    (r"^\d{4}$", "%Y", ""),
    (r"^\d{4}年$", "%Y年", ""),
    (r"^\d{2}$", "%y", ""),
    (r"^\d{2}年$", "%y年", ""),
    (r"^\d{4}-\d{2}$", "%Y-%m", ""),
    (r"^\d{2}-\d{2}$", "%y-%m", ""),
    (r"^\d{4}\.\d{2}$", "%Y.%m", ""),
    (r"^\d{2}\.\d{2}$", "%y.%m", ""),
    (r"^\d{2}:\d{2}$", "%H:%M", "Ymd"),
    (r"^\d{4}年\d{2}月$", "%Y年%m月", ""),
    (r"^\d{2}年\d{2}月$", "%y年%m月", ""),
    (r"^\d{2}月\d{2}日$", "%m月%d日", "Y"),
    (r"^\d{4}-\d{2}-\d{2}$", "%Y-%m-%d", ""),
    (r"^\d{2}-\d{2}-\d{2}$", "%y-%m-%d", ""),
    (r"^\d{4}\.\d{2}\.\d{2}$", "%Y.%m.%d", ""),
    (r"^\d{2}:\d{2}:\d{2}$", "%H:%M:%S", "Ymd"),
    (r"^\d{2}\.\d{2}\.\d{2}$", "%y.%m.%d", ""),
    (r"^\d{4}/\d{2}/\d{2}$", "%Y/%m/%d", ""),
    (r"^\d{2}/\d{2}/\d{2}$", "%y/%m/%d", ""),
    (r"^\d{4}年\d{2}月\d{2}日$", "%Y年%m月%d日", ""),
    (r"^\d{2}年\d{2}月\d{2}日$", "%y年%m月%d日", ""),
    (r"^\d{4}年\d{2}月\d{2}日 \d{2}:\d{2}$", "%Y年%m月%d日 %H:%M", ""),
    (r"^\d{2}年\d{2}月\d{2}日 \d{2}:\d{2}$", "%y年%m月%d日 %H:%M", ""),
    (r"^\d{2}月\d{2}日 \d{2}:\d{2}$", "%m月%d日 %H:%M", "Y"),
    (r"^\d{4}年\d{2}月\d{2}日 \d{2}:\d{2}:\d{2}$", "%Y年%m月%d日 %H:%M:%S", ""),
    (r"^\d{2}年\d{2}月\d{2}日 \d{2}:\d{2}:\d{2}$", "%y年%m月%d日 %H:%M:%S", ""),
    (r"^\d{2}月\d{2}日 \d{2}:\d{2}:\d{2}$", "%m月%d日 %H:%M:%S", "Y"),
    (r"^\d{4}/\d{2}/\d{2} \d{2}:\d{2}:\d{2}$", "%Y/%m/%d %H:%M:%S", ""),
    (r"^\d{2}/\d{2}/\d{2} \d{2}:\d{2}:\d{2}$", "%y/%m/%d %H:%M:%S", ""),
    (r"^\d{4}\.\d{2}\.\d{2} \d{2}:\d{2}:\d{2}$", "%Y.%m.%d %H:%M:%S", ""),
    (r"^\d{2}\.\d{2}\.\d{2} \d{2}:\d{2}:\d{2}$", "%y.%m.%d %H:%M:%S", ""),
    (r"^\d{4}/\d{2}/\d{2} \d{2}:\d{2}$", "%Y/%m/%d %H:%M", ""),
    (r"^\d{2}/\d{2}/\d{2} \d{2}:\d{2}$", "%y/%m/%d %H:%M", ""),
    (r"^\d{4}-\d{2}-\d{2} \d{2}:\d{2}$", "%Y-%m-%d %H:%M", ""),
    (r"^\d{2}-\d{2}-\d{2} \d{2}:\d{2}$", "%y-%m-%d %H:%M", ""),
    (r"^\d{4}\.\d{2}\.\d{2} \d{2}:\d{2}$", "%Y.%m.%d %H:%M", ""),
    (r"^\d{2}\.\d{2}\.\d{2} \d{2}:\d{2}$", "%y.%m.%d %H:%M", ""),
]


# 此处pattern直接引用的KingName 南哥的GNE里面的匹配规则 站在巨人肩膀优化代码
# https://github.com/GeneralNewsExtractor/GeneralNewsExtractor/blob/master/gne/defaults.py
DATETIME_PATTERN = {
    r"(\d{4}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[0-1]?[0-9]:[0-5]?[0-9]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M", "S")],
    r"(\d{4}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[2][0-3]:[0-5]?[0-9]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M", "S")],
    r"(\d{4}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[0-1]?[0-9]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M")],
    r"(\d{4}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[2][0-3]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M")],
    # r"(\d{4}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[1-24]\d时[0-60]\d分)([1-24]\d时)": [("Y", "m", "d", "H", "M"), ("H",)],
    r"(\d{4}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[0-23]时[0-59]分)([0-23]时)": [("Y", "m", "d", "H", "M"), ("H",)],
    r"(\d{2}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[0-1]?[0-9]:[0-5]?[0-9]:[0-5]?[0-9])": [("y", "m", "d", "H", "M", "S")],
    r"(\d{2}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[2][0-3]:[0-5]?[0-9]:[0-5]?[0-9])": [("y", "m", "d", "H", "M", "S")],
    r"(\d{2}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[0-1]?[0-9]:[0-5]?[0-9])": [("y", "m", "d", "H", "M")],
    r"(\d{2}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[2][0-3]:[0-5]?[0-9])": [("y", "m", "d", "H", "M")],
    # r"(\d{2}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[1-24]\d时[0-60]\d分)([1-24]\d时)": [("y", "m", "d", "H", "M"), ("H",)],
    r"(\d{2}[-|/|.]\d{1,2}[-|/|.]\d{1,2}\s*?[0-23]时[0-59]分)([0-23]时)": [("y", "m", "d", "H", "M"), ("H",)],
    r"(\d{4}年\d{1,2}月\d{1,2}日\s*?[0-1]?[0-9]:[0-5]?[0-9]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M", "S")],
    r"(\d{4}年\d{1,2}月\d{1,2}日\s*?[2][0-3]:[0-5]?[0-9]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M", "S")],
    r"(\d{4}年\d{1,2}月\d{1,2}日\s*?[0-1]?[0-9]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M")],
    r"(\d{4}年\d{1,2}月\d{1,2}日\s*?[2][0-3]:[0-5]?[0-9])": [("Y", "m", "d", "H", "M")],
    # r"(\d{4}年\d{1,2}月\d{1,2}日\s*?[1-24]\d时[0-60]\d分)([1-24]\d时)": [("Y", "m", "d", "H", "M"), ("H",)],
    r"(\d{4}年\d{1,2}月\d{1,2}日\s*?[0-23]时[0-59]分)([0-23]时)": [("Y", "m", "d", "H", "M"), ("H",)],
    r"(\d{2}年\d{1,2}月\d{1,2}日\s*?[0-1]?[0-9]:[0-5]?[0-9]:[0-5]?[0-9])": [("y", "m", "d", "H", "M", "S")],
    r"(\d{2}年\d{1,2}月\d{1,2}日\s*?[2][0-3]:[0-5]?[0-9]:[0-5]?[0-9])": [("y", "m", "d", "H", "M", "S")],
    r"(\d{2}年\d{1,2}月\d{1,2}日\s*?[0-1]?[0-9]:[0-5]?[0-9])": [("y", "m", "d", "H", "M", "S")],
    r"(\d{2}年\d{1,2}月\d{1,2}日\s*?[2][0-3]:[0-5]?[0-9])": [("y", "m", "d", "H", "M")],
    # r"(\d{2}年\d{1,2}月\d{1,2}日\s*?[1-24]\d时[0-60]\d分)([1-24]\d时)": [("y", "m", "d", "H", "M"), ("H",)],
    r"(\d{2}年\d{1,2}月\d{1,2}日\s*?[0-23]时[0-59]分)([0-23]时)": [("y", "m", "d", "H", "M"), ("H",)],
    r"(\d{1,2}月\d{1,2}日\s*?[0-1]?[0-9]:[0-5]?[0-9]:[0-5]?[0-9])": [("m", "d", "H", "M", "S")],
    r"(\d{1,2}月\d{1,2}日\s*?[2][0-3]:[0-5]?[0-9]:[0-5]?[0-9])": [("m", "d", "H", "M", "S")],
    r"(\d{1,2}月\d{1,2}日\s*?[0-1]?[0-9]:[0-5]?[0-9])": [("m", "d", "H", "M")],
    r"(\d{1,2}月\d{1,2}日\s*?[2][0-3]:[0-5]?[0-9])": [("m", "d", "H", "M")],
    # r"(\d{1,2}月\d{1,2}日\s*?[1-24]\d时[0-60]\d分)([1-24]\d时)": [("m", "d", "H", "M"), ("H",)],
    r"(\d{1,2}月\d{1,2}日\s*?[0-23]时[0-59]分)([0-23]时)": [("m", "d", "H", "M"), ("H",)],
    r"(\d{4}[-|/|.]\d{1,2}[-|/|.]\d{1,2})": [("Y", "m", "d")],
    r"(\d{2}[-|/|.]\d{1,2}[-|/|.]\d{1,2})": [("y", "m", "d")],
    r"(\d{4}年\d{1,2}月\d{1,2}日)": [("Y", "m", "d")],
    r"(\d{2}年\d{1,2}月\d{1,2}日)": [("y", "m", "d")],
    r"(\d{1,2}月\d{1,2}日)": [("m", "d")]
}
